@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -27,14 +29,27 @@ class BatchModifyDomainInfoRequest(AbstractModel):
         :type Domains: list of str
         :param TemplateId: 模板ID。
         :type TemplateId: str
+        :param LockTransfer: true： 开启60天内禁止转移注册商锁定
+false：关闭60天内禁止转移注册商锁定
+默认 true
+        :type LockTransfer: bool
         """
         self.Domains = None
         self.TemplateId = None
+        self.LockTransfer = None
 
 
     def _deserialize(self, params):
         self.Domains = params.get("Domains")
         self.TemplateId = params.get("TemplateId")
+        self.LockTransfer = params.get("LockTransfer")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class BatchModifyDomainInfoResponse(AbstractModel):
@@ -56,6 +71,13 @@ class BatchModifyDomainInfoResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class BatchStatus(AbstractModel):
@@ -81,6 +103,13 @@ class BatchStatus(AbstractModel):
         self.LogId = params.get("LogId")
         self.Status = params.get("Status")
         self.BatchAction = params.get("BatchAction")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CertificateInfo(AbstractModel):
@@ -134,6 +163,13 @@ GZJGZY: 公证机构执业证。
         self.CertificateCode = params.get("CertificateCode")
         self.CertificateType = params.get("CertificateType")
         self.ImgUrl = params.get("ImgUrl")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CheckBatchStatusRequest(AbstractModel):
@@ -151,6 +187,13 @@ class CheckBatchStatusRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.LogIds = params.get("LogIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CheckBatchStatusResponse(AbstractModel):
@@ -177,6 +220,13 @@ class CheckBatchStatusResponse(AbstractModel):
                 obj._deserialize(item)
                 self.StatusSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CheckDomainRequest(AbstractModel):
@@ -198,6 +248,13 @@ class CheckDomainRequest(AbstractModel):
     def _deserialize(self, params):
         self.DomainName = params.get("DomainName")
         self.Period = params.get("Period")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CheckDomainResponse(AbstractModel):
@@ -225,7 +282,7 @@ class CheckDomainResponse(AbstractModel):
         :param FeeRenew: 溢价词的续费价格
 注意：此字段可能返回 null，表示取不到有效值。
         :type FeeRenew: int
-        :param RealPrice: 域名真实价格
+        :param RealPrice: 域名真实价格, 溢价词时价格跟年限有关，非溢价词时价格为1年的价格
 注意：此字段可能返回 null，表示取不到有效值。
         :type RealPrice: int
         :param FeeTransfer: 溢价词的转入价格
@@ -271,6 +328,13 @@ class CheckDomainResponse(AbstractModel):
         self.Period = params.get("Period")
         self.RecordSupport = params.get("RecordSupport")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ContactInfo(AbstractModel):
@@ -348,6 +412,13 @@ class ContactInfo(AbstractModel):
         self.Province = params.get("Province")
         self.City = params.get("City")
         self.Country = params.get("Country")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateDomainBatchRequest(AbstractModel):
@@ -363,18 +434,21 @@ class CreateDomainBatchRequest(AbstractModel):
         :type Period: int
         :param Domains: 批量购买的域名,最多为4000个
         :type Domains: list of str
-        :param PayMode: 付费模式 0手动在线付费，1使用余额付费
+        :param PayMode: 付费模式 0手动在线付费，1使用余额付费，2使用特惠包
         :type PayMode: int
         :param AutoRenewFlag: 自动续费开关。有两个可选值：
 0 表示关闭，不自动续费（默认值）
 1 表示开启，将自动续费
         :type AutoRenewFlag: int
+        :param PackageResourceId: 使用的特惠包ID，PayMode为2时必填
+        :type PackageResourceId: str
         """
         self.TemplateId = None
         self.Period = None
         self.Domains = None
         self.PayMode = None
         self.AutoRenewFlag = None
+        self.PackageResourceId = None
 
 
     def _deserialize(self, params):
@@ -383,6 +457,14 @@ class CreateDomainBatchRequest(AbstractModel):
         self.Domains = params.get("Domains")
         self.PayMode = params.get("PayMode")
         self.AutoRenewFlag = params.get("AutoRenewFlag")
+        self.PackageResourceId = params.get("PackageResourceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateDomainBatchResponse(AbstractModel):
@@ -405,6 +487,13 @@ class CreateDomainBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateTemplateRequest(AbstractModel):
@@ -430,6 +519,13 @@ class CreateTemplateRequest(AbstractModel):
         if params.get("CertificateInfo") is not None:
             self.CertificateInfo = CertificateInfo()
             self.CertificateInfo._deserialize(params.get("CertificateInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateTemplateResponse(AbstractModel):
@@ -453,6 +549,13 @@ class CreateTemplateResponse(AbstractModel):
             self.Template = TemplateInfo()
             self.Template._deserialize(params.get("Template"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteTemplateRequest(AbstractModel):
@@ -470,6 +573,13 @@ class DeleteTemplateRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TemplateId = params.get("TemplateId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteTemplateResponse(AbstractModel):
@@ -487,6 +597,13 @@ class DeleteTemplateResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeBatchOperationLogDetailsRequest(AbstractModel):
@@ -512,6 +629,13 @@ class DescribeBatchOperationLogDetailsRequest(AbstractModel):
         self.LogId = params.get("LogId")
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeBatchOperationLogDetailsResponse(AbstractModel):
@@ -543,6 +667,13 @@ class DescribeBatchOperationLogDetailsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.DomainBatchDetailSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeBatchOperationLogsRequest(AbstractModel):
@@ -564,6 +695,13 @@ class DescribeBatchOperationLogsRequest(AbstractModel):
     def _deserialize(self, params):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeBatchOperationLogsResponse(AbstractModel):
@@ -595,6 +733,13 @@ class DescribeBatchOperationLogsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.DomainBatchLogSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeDomainBaseInfoRequest(AbstractModel):
@@ -612,6 +757,13 @@ class DescribeDomainBaseInfoRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Domain = params.get("Domain")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeDomainBaseInfoResponse(AbstractModel):
@@ -623,10 +775,14 @@ class DescribeDomainBaseInfoResponse(AbstractModel):
         """
         :param DomainInfo: 域名信息
         :type DomainInfo: :class:`tencentcloud.domain.v20180808.models.DomainBaseInfo`
+        :param Uin: 用户Uin
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Uin: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.DomainInfo = None
+        self.Uin = None
         self.RequestId = None
 
 
@@ -634,7 +790,15 @@ class DescribeDomainBaseInfoResponse(AbstractModel):
         if params.get("DomainInfo") is not None:
             self.DomainInfo = DomainBaseInfo()
             self.DomainInfo._deserialize(params.get("DomainInfo"))
+        self.Uin = params.get("Uin")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeDomainNameListRequest(AbstractModel):
@@ -656,6 +820,13 @@ class DescribeDomainNameListRequest(AbstractModel):
     def _deserialize(self, params):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeDomainNameListResponse(AbstractModel):
@@ -687,6 +858,13 @@ class DescribeDomainNameListResponse(AbstractModel):
                 self.DomainSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeDomainPriceListRequest(AbstractModel):
@@ -712,6 +890,13 @@ class DescribeDomainPriceListRequest(AbstractModel):
         self.TldList = params.get("TldList")
         self.Year = params.get("Year")
         self.Operation = params.get("Operation")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeDomainPriceListResponse(AbstractModel):
@@ -738,6 +923,13 @@ class DescribeDomainPriceListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PriceList.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeTemplateListRequest(AbstractModel):
@@ -755,11 +947,14 @@ class DescribeTemplateListRequest(AbstractModel):
         :type Type: str
         :param Status: 认证状态：未实名认证:NotUpload, 实名审核中:InAudit，已实名认证:Approved，实名审核失败:Reject
         :type Status: str
+        :param Keyword: 域名所有者筛选
+        :type Keyword: str
         """
         self.Offset = None
         self.Limit = None
         self.Type = None
         self.Status = None
+        self.Keyword = None
 
 
     def _deserialize(self, params):
@@ -767,6 +962,14 @@ class DescribeTemplateListRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Type = params.get("Type")
         self.Status = params.get("Status")
+        self.Keyword = params.get("Keyword")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeTemplateListResponse(AbstractModel):
@@ -797,6 +1000,13 @@ class DescribeTemplateListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.TemplateSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeTemplateRequest(AbstractModel):
@@ -814,6 +1024,13 @@ class DescribeTemplateRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TemplateId = params.get("TemplateId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeTemplateResponse(AbstractModel):
@@ -837,6 +1054,13 @@ class DescribeTemplateResponse(AbstractModel):
             self.Template = TemplateInfo()
             self.Template._deserialize(params.get("Template"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DomainBaseInfo(AbstractModel):
@@ -910,6 +1134,11 @@ xinnet: Xin Net Technology Corporation（北京新网数码信息技术有限公
         :type RegistrarType: str
         :param NameServer: 域名绑定的ns
         :type NameServer: list of str
+        :param LockTransfer: true：开启锁定
+false：关闭锁定
+        :type LockTransfer: bool
+        :param LockEndTime: 锁定结束时间
+        :type LockEndTime: str
         """
         self.DomainId = None
         self.DomainName = None
@@ -923,6 +1152,8 @@ xinnet: Xin Net Technology Corporation（北京新网数码信息技术有限公
         self.BuyStatus = None
         self.RegistrarType = None
         self.NameServer = None
+        self.LockTransfer = None
+        self.LockEndTime = None
 
 
     def _deserialize(self, params):
@@ -938,6 +1169,15 @@ xinnet: Xin Net Technology Corporation（北京新网数码信息技术有限公
         self.BuyStatus = params.get("BuyStatus")
         self.RegistrarType = params.get("RegistrarType")
         self.NameServer = params.get("NameServer")
+        self.LockTransfer = params.get("LockTransfer")
+        self.LockEndTime = params.get("LockEndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DomainBatchDetailSet(AbstractModel):
@@ -979,6 +1219,13 @@ success  操作成功。
         self.Reason = params.get("Reason")
         self.CreatedOn = params.get("CreatedOn")
         self.UpdatedOn = params.get("UpdatedOn")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DomainBatchLogSet(AbstractModel):
@@ -1010,6 +1257,13 @@ done 执行完成。
         self.Number = params.get("Number")
         self.Status = params.get("Status")
         self.CreatedOn = params.get("CreatedOn")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DomainList(AbstractModel):
@@ -1075,6 +1329,13 @@ TransferFailed：转入失败
         self.Tld = params.get("Tld")
         self.CodeTld = params.get("CodeTld")
         self.BuyStatus = params.get("BuyStatus")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyDomainDNSBatchRequest(AbstractModel):
@@ -1096,6 +1357,13 @@ class ModifyDomainDNSBatchRequest(AbstractModel):
     def _deserialize(self, params):
         self.Domains = params.get("Domains")
         self.Dns = params.get("Dns")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyDomainDNSBatchResponse(AbstractModel):
@@ -1117,6 +1385,13 @@ class ModifyDomainDNSBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyDomainOwnerBatchRequest(AbstractModel):
@@ -1138,6 +1413,13 @@ class ModifyDomainOwnerBatchRequest(AbstractModel):
     def _deserialize(self, params):
         self.Domains = params.get("Domains")
         self.NewOwnerUin = params.get("NewOwnerUin")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyDomainOwnerBatchResponse(AbstractModel):
@@ -1159,6 +1441,13 @@ class ModifyDomainOwnerBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class PriceInfo(AbstractModel):
@@ -1192,6 +1481,13 @@ class PriceInfo(AbstractModel):
         self.Price = params.get("Price")
         self.RealPrice = params.get("RealPrice")
         self.Operation = params.get("Operation")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RenewDomainBatchRequest(AbstractModel):
@@ -1224,6 +1520,13 @@ class RenewDomainBatchRequest(AbstractModel):
         self.Domains = params.get("Domains")
         self.PayMode = params.get("PayMode")
         self.AutoRenewFlag = params.get("AutoRenewFlag")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RenewDomainBatchResponse(AbstractModel):
@@ -1245,6 +1548,13 @@ class RenewDomainBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SetDomainAutoRenewRequest(AbstractModel):
@@ -1269,6 +1579,13 @@ class SetDomainAutoRenewRequest(AbstractModel):
     def _deserialize(self, params):
         self.DomainId = params.get("DomainId")
         self.AutoRenew = params.get("AutoRenew")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class SetDomainAutoRenewResponse(AbstractModel):
@@ -1286,6 +1603,13 @@ class SetDomainAutoRenewResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TemplateInfo(AbstractModel):
@@ -1347,6 +1671,13 @@ class TemplateInfo(AbstractModel):
             self.ContactInfo._deserialize(params.get("ContactInfo"))
         self.IsValidTemplate = params.get("IsValidTemplate")
         self.InvalidReason = params.get("InvalidReason")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TransferInDomainBatchRequest(AbstractModel):
@@ -1368,12 +1699,17 @@ class TransferInDomainBatchRequest(AbstractModel):
 0 表示关闭，不自动续费（默认值）
 1 表示开启，将自动续费
         :type AutoRenewFlag: int
+        :param LockTransfer: true： 开启60天内禁止转移注册商锁定
+false：关闭60天内禁止转移注册商锁定
+默认 true
+        :type LockTransfer: bool
         """
         self.Domains = None
         self.PassWords = None
         self.TemplateId = None
         self.PayMode = None
         self.AutoRenewFlag = None
+        self.LockTransfer = None
 
 
     def _deserialize(self, params):
@@ -1382,6 +1718,14 @@ class TransferInDomainBatchRequest(AbstractModel):
         self.TemplateId = params.get("TemplateId")
         self.PayMode = params.get("PayMode")
         self.AutoRenewFlag = params.get("AutoRenewFlag")
+        self.LockTransfer = params.get("LockTransfer")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TransferInDomainBatchResponse(AbstractModel):
@@ -1403,6 +1747,13 @@ class TransferInDomainBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TransferProhibitionBatchRequest(AbstractModel):
@@ -1426,6 +1777,13 @@ False：关闭禁止域名转移状态。
     def _deserialize(self, params):
         self.Domains = params.get("Domains")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TransferProhibitionBatchResponse(AbstractModel):
@@ -1447,6 +1805,13 @@ class TransferProhibitionBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class UpdateProhibitionBatchRequest(AbstractModel):
@@ -1470,6 +1835,13 @@ False：关闭禁止域名更新状态。
     def _deserialize(self, params):
         self.Domains = params.get("Domains")
         self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class UpdateProhibitionBatchResponse(AbstractModel):
@@ -1491,6 +1863,13 @@ class UpdateProhibitionBatchResponse(AbstractModel):
     def _deserialize(self, params):
         self.LogId = params.get("LogId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class UploadImageRequest(AbstractModel):
@@ -1508,6 +1887,13 @@ class UploadImageRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ImageFile = params.get("ImageFile")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class UploadImageResponse(AbstractModel):
@@ -1528,4 +1914,11 @@ class UploadImageResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.AccessUrl = params.get("AccessUrl")
-        self.RequestId = params.get("RequestId")
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
